cgexplore.optimisation
======================

.. automodule:: cgexplore.optimisation

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: class.rst
      :nosignatures:
   
      CGOMMDynamics
      CGOMMOptimizer
      CGOMMSinglePoint
      OMMTrajectory
   
   


   
   
   

   
   
   



